#!/bin/bash

### Custom bash script for
### SmartStart Scripting Toolkit for Linux v1.9
### May 2008
### JimmyV

sleep 10s
clear

### Get environment variables
### must use absolute path here
source /mnt/main/scripts/includes


echo -e "*** Copying over toolkit scripts and utilites into RAM drive ***"
cd ${TOOLKIT}
mkdir ${RAM_DATA_FILES}
cp -a ${RAM_TOOLKIT_DIR}/scripts/* ${TOOLKIT}
cp -a ${RAM_TOOLKIT_DIR}/utilities/* ${TOOLKIT}
cp -a ${RAM_TOOLKIT_DIR}/data_files/ ${TOOLKIT}
echo -e "*** Scripts will continue execution from RAM drive ***"

## With support for ProLiant 100 series systems we use dmidecode
## to get product type and serial number

## occasionally the product name will have whitespace at the end. Our grep output
## has whitespace at the beginning so we use sed to remove the whitespace from each end

echo -e "*** Detecting system type ***\n"

export PRODUCT_NAME="`dmidecode | grep -m1 "Product Name:" | cut -d : -f 2 | sed 's/^[ \t]*//;s/[ \t]*$//'`"
export SERIAL_ID="`dmidecode | grep -m1 "Serial Number:" | cut -d : -f 2 | sed 's/^[ \t]*//;s/[ \t]*$//'`"

## for use as files we don't want any spaces in the name
# LNAME (Long_Name) is full system name with spaces removed 
export PRODUCT_LNAME="`echo ${PRODUCT_NAME}| tr -d " "`"

# SNAME (Short_Name) drops the word ProLiant 
export PRODUCT_SNAME="`echo ${PRODUCT_NAME} | cut -c 10-`"

echo -e "  -System is a ${PRODUCT_NAME}\n"


## mount writable NFS area
echo "*** Setting up NFS mount to save data ***"
mkdir -p ${RAM_PROFILE_DIR}
mount -t nfs ${NFS_SERVER_IP}:${NFS_PROFILE_DIR} ${RAM_PROFILE_DIR} -o rw,nolock,sync
if [ $? != 0 ]; then
	echo "Unable to mount NFS share, make sure correct NFS server information is in includes"
	exec /bin/bash
fi

## Create directory for data files to be saved
mkdir -p ${RAM_PROFILE_DIR}/${SERIAL_ID}

## Define system series and architecture

source system-id

cd ${TOOLKIT}

echo -e "*** Loading storage & network drivers ***"
./load_modules.sh
echo -e "...Pausing to allow drivers to finish loading\n"
sleep 5s


if [ ${SERIES} = 100 ];
	then
		echo -e "100 Series ProLiant detected, skipping hardware discovery"
		
    else

    ## run hardware discovery to get hard drive information
    ./hpdiscovery -f ${HWDISC_FILE}

    ## Find and set boot device
    export "`./hwquery ${HWDISC_FILE} allboards.xml BOOTDEVNODE=DevNode`";

    ### Capture system BIOS settings

    ./conrep -s -f${RAM_PROFILE_DIR}/${SERIAL_ID}/${PRODUCT_LNAME}_conrep.dat
    if [ $? = 0 ] ;
		then
			echo "System Configuration saved to ${RAM_PROFILE_DIR}/${SERIAL_ID}/${PRODUCT_LNAME}_conrep.dat"
			sleep 5s
    fi

    ### Capture Array Controller settings
    ### If more than one array controller all info will be contained in one file

    ./ifhw ${HWDISC_FILE} allboards.xml "PCI:Smart Array" 2> /dev/null
    if [ $? = 0 ] ; 
   		then
        export ARRAY_CTL=SmartArray
   	    cd ${TOOLKIT}/cpqacuxe
		./cpqacuxe -c ${RAM_PROFILE_DIR}/${SERIAL_ID}/${ARRAY_CTL}_acu.dat 2> /dev/null
		sleep 5s
	if [ $? = 0 ] ; 
	    then
		echo "Array Configuration saved to ${RAM_PROFILE_DIR}/${SERIAL_ID}/${ARRAY_CTL}_acu.dat"
	fi
	    else
		echo "Smart Array controller not detected, no ACU configuration captured."
	fi

	cd ${TOOLKIT}

	./ifhw ${HWDISC_FILE} allboards.xml "PCI:Integrated Lights-Out" 2> /dev/null
	if [ $? = 0 ] ; 
    	then
    		./hponcfg -w ${RAM_PROFILE_DIR}/${SERIAL_ID}/hponcfg.dat 2> /dev/null
	    if [ $? = 0 ] ; 
			then
				echo "Integrated Lights-Out Configuration Report saved to ${RAM_PROFILE_DIR}/${SERIAL_ID}/hponcfg.dat"
				echo " - this is not a RIBCL configuration script"
		fi
	fi


	# copy hwdiscovery file to NFS mount 
	# the file can be parsed for additional info like MAC addresses

	cp ${HWDISC_FILE}  ${RAM_PROFILE_DIR}/${SERIAL_ID}/hw_discovery.dat

	umount ${RAM_PROFILE_DIR}

## if end for 100 series
fi

cd ${TOOLKIT}

echo -e "*** System capture complete ***\n"
exec /bin/bash

