#!/bin/bash

### Custom bash script for
### SmartStart Scripting Toolkit for Linux v1.9
### May 2008
### JimmyV


clear
echo -e "*** Executing script to configure hardware (config_hw.sh)\n"
 
sleep 2s

cd ${TOOLKIT}

### Future Series 100 systems will have some configuration options
### skip 100 series for now
 
if [ ${SERIES} != 100 ];

    then
	echo -e "*** Setting DEPLOY state to 2 in System ROM ***\n" 
	./statemgr -W DEPLOY 2 > /dev/null
    
    ### Begin iLO(2) configuration

	echo -e "*** Configuring iLO now... ***"
    if [ -f ${RAM_DATA_FILES}/${SERIAL_ID}/hponcfg.dat ];
	then
	    # use server specific hponcfg file
	    ./hponcfg -f ${RAM_DATA_FILES}/${SERIAL_ID}/hponcfg.dat
	    echo -e "  -iLO configuration set using file for ${SERIAL_ID}\n"
	else
	    if [ -f ${RAM_DATA_FILES}/hponcfg.dat ];
		then
		    # use generic hponcfg file
		    ./hponcfg -f ${RAM_DATA_FILES}/hponcfg.dat
		    echo -e "  -iLO configuration set using generic file\n"
		else
		    echo -e "  -iLO configuration file not found\n"
	    fi	
    fi
	
    sleep 2s
    ### End iLO(2) configuration

    ### Begin System ROM configuration

    ### CONREP file created using capture.sh use the following
    ### naming convention are named ${PRODUCT_LNAME}_conrep.dat
    ### EXAMPLE: ProLaintDL360G3_conrep.dat
    ###
    ### You can have individual conrep files based on the server
    ### serial number ${SERIAL_ID}.
    ### If no individual file is found script will use default
    ### conrep.dat file
    ###
    ### if you see an error 2 reported, conrep could not find a file
    ###
    ### CPQACUXE naming convention is similiar
    ###
    ### Add additional controllers as needed
    ###

    echo -e "*** Conrep is configuring system settings ***"
    # check for server specific conrep file
    if [ -f ${RAM_DATA_FILES}/${SERIAL_ID}/${PRODUCT_LNAME}_conrep.dat ];
	then
	    # use server specific conrep file
	    ./conrep -L -f${RAM_DATA_FILES}/${SERIAL_ID}/${PRODUCT_LNAME}_conrep.dat
	    echo -e "  -NVRAM configuration set using ${PRODUCT_LNAME}_conrep.dat for ${SERIAL_ID}\n"
	else
	    # use generic conrep file
	    if [ -f ${RAM_DATA_FILES}/${SERIAL_ID}/${PRODUCT_LNAME}_conrep.dat ];
		then
		    # use server specific conrep file
		    ./conrep -L -f${RAM_DATA_FILES}/${PRODUCT_LNAME}_conrep.dat
		    echo -e "  -NVRAM configuration set using generic ${PRODUCT_LNAME}_conrep.dat\n"
		else
		    echo -e "  -NVRAM configuration file not found\n" 
	    fi	
    fi

    ### End System ROM configuration

    ### Begin Smart Array configuration
    
    ./ifhw ${HWDISC_FILE} allboards.xml "PCI:Smart Array" 2> /dev/null
    if [ $? = 0 ] ;
	then
	    export "`./hwquery ${HWDISC_FILE} allboards.xml "ARRAY_CTL_TYPE=Smart Array"`" # | tr -d " "`";
	    echo -e "*** ${ARRAY_CTL_TYPE} found ***"
	    export ARRAY_CTL=SmartArray
	    cd ${TOOLKIT}/cpqacuxe
	    # check for server specific cpqacuxe file
	    if [ -f ${RAM_DATA_FILES}/${SERIAL_ID}/${ARRAY_CTL}_acu.dat ];
		then
		    # destroy current controller configuration
		    # from POST configure or previous settings
		    ./cpqacuxe -i ${RAM_DATA_FILES}/clear-controller.dat
		    sleep 2s
		    # use server specific cpqacuxe file
		    ./cpqacuxe -i ${RAM_DATA_FILES}/${SERIAL_ID}/${ARRAY_CTL}_acu.dat 
		    echo -e "  -Array configuration set using ${ARRAY_CTL}_acu.dat file for ${SERIAL_ID}\n"
		else
		    if [ -f ${RAM_DATA_FILES}/${ARRAY_CTL}_acu.dat ];
			then
			    ##  use generic cpqacuxe file
			    ./cpqacuxe -i ${RAM_DATA_FILES}/${ARRAY_CTL}_acu.dat 
			    echo -e "  -Array configuration set using generic array configuration\n"
			else
			    # use current config auto-set during POST
			    echo -e "  -Using POST defined Smart Array configuration\n"
		    fi	
	    fi	
    fi

    ### End Smart Array configuration

    cd ${TOOLKIT}
    
    ### Begin SATA Raid configuration
 
    ./ifhw ${HWDISC_FILE} allboards.xml "PCI:Intel(R) 82801GR SATA RAID Controller" 2> /dev/null
    if [ $? = 0 ] ; 
	then
	    echo "Intel(R) 82801GR SATA RAID Controller found"
	    # reset to defaults and create a raid1 logical drive
	    # clear current raid configuration
	    hrconf setconfig 1 default noprompt  &>/dev/null
	    sleep 5s
	    hrconf rescan 1 &>/dev/null
	    sleep 10s
	    echo "*** Configuring RAID controller"
	    # 2 drives setup as a mirrored pair
	    hrconf create 1 logicaldrive Name MirrorSet1 Init_Method QUICK max 1 0 1 0 2 noprompt &>/dev/null
    fi

    ### End SATA Raid configuration

    ### Another Example for plain SATA
    ./ifhw ${HWDISC_FILE} allboards.xml "PCI:Intel(R) 82801GR SATA Controller" 2> /dev/null
    if [ $? = 0 ] ; 
	then
	    echo "Plain SATA found"
    fi
    ### End plain SATA

    echo -e "*** Completed hardware configuration..."
    sleep 5s

    #########################################################
    # Set system time/date and create custom post message 
    # in system rom
    # read info in settime.sh to make functional
    source settime.sh
    ########################################################

# End fi for 100 series check
fi

#pass control to local disk prep script

#debug break pount
#exec /bin/bash

if [ "$DISTRO" = "WINDOWS" ]
    then
	./land_windows.sh
    else
	./land_install.sh
fi

echo "WAH if your seeing this something bad happened!!!!"
exec /bin/bash
