#!/bin/bash

## CONTINUE COMMON INSTALL PROCESS

cd ${TOOLKIT}

echo "Pausing to allow drivers to catch up"
sleep 5

echo ""
echo "Rerun hardware discovery to find boot device"
./hpdiscovery -f ${HWDISC_FILE}

## use hwquery to fetch the boot dev node from hardware discovery file.
if [ -z ${BOOTDEVNODE} ]; then
	export `./hwquery ${HWDISC_FILE} allboards.xml BOOTDEVNODE=DevNode`
fi

echo "Boot Device=${BOOTDEVNODE}"

if [ -z ${BOOTDEVNODE} ]; then
	echo "MISSING boot device dev node. Check that the drivers are loaded."
	exec /bin/bash
fi

ls -al ${BOOTDEVNODE}*
ln -s ${BOOTDEVNODE} /dev/sssd


echo "*** Preparing Windows Unattended Install ***"

echo "clearing mbr and a few more sectors"
dd if=/dev/zero of=/dev/sssd bs=512 count=32

echo "forcing kernel to re-read partition table"
sfdisk --re-read /dev/sssd
sleep 5

echo "landing mbr"
dd if=${RAM_TOOLKIT_DIR}/windows_unattend/freedos.mbr of=/dev/sssd bs=512 count=1

echo "create new 2048 FAT16 partition using sfdisk"
echo "0,2048,6,*" | sfdisk -uM -D /dev/sssd

echo "forcing kernel to re-read partition table"
sfdisk --re-read /dev/sssd

## make symlink for first partition, usually sda1 or c0d0p1
if test -e ${BOOTDEVNODE}1 ; then
	ln -s ${BOOTDEVNODE}1 /dev/sssd1
elif test -e ${BOOTDEVNODE}p1 ; then
	ln -s ${BOOTDEVNODE}p1 /dev/sssd1
else
	echo "Partition 1 missing, check that partition creation succeeded"
	exec /bin/bash
fi

ls -la /dev/sssd1

echo "creating FAT filesystem"
mkdosfs -F 16 /dev/sssd1

## create boot sector
cp ${RAM_TOOLKIT_DIR}/windows_unattend/freedos.bss ${TOOLKIT}
dd if=/dev/sssd1 bs=1 count=8 skip=3 of=${TOOLKIT}/freedos.bss seek=3 conv=notrunc >/dev/null
dd if=/dev/sssd1 bs=1 count=51 skip=11 of=${TOOLKIT}/freedos.bss seek=11 conv=notrunc >/dev/null

## for some insane reason, the number of hidden sectors and the boot drive is lost by mkdosfs, these lines fix that.
echo -ne "\040" | dd of=${TOOLKIT}/freedos.bss bs=1 seek=28 conv=notrunc >/dev/null
echo -ne "\200" | dd of=${TOOLKIT}/freedos.bss bs=1 seek=36 conv=notrunc >/dev/null

## write boot sector and backup boot sector
dd if=${TOOLKIT}/freedos.bss of=/dev/sssd1 bs=512 count=1
dd if=${TOOLKIT}/freedos.bss of=/dev/sssd1 bs=512 count=1 seek=6

## mount disk
echo "mounting to /mnt/dos"
mount -t vfat -o fat=16 /dev/sssd1 /mnt/dos

echo "Setting up bootstrap install"
cp -a ${RAM_TOOLKIT_DIR}/windows_unattend/kernel.sys /mnt/dos/
cp -a ${RAM_TOOLKIT_DIR}/windows_unattend/command.com /mnt/dos/
cp -a ${RAM_TOOLKIT_DIR}/windows_unattend/autoexec.bat /mnt/dos/
cp -a ${RAM_TOOLKIT_DIR}/windows_unattend/config.sys /mnt/dos/

###

cd ${TOOLKIT}
