#!/bin/bash

### Custom bash script for
### SmartStart Scripting Toolkit for Linux v1.8
### October 2007
### JimmyV

clear
echo -e "*** Executing script to land installation on local drive (land_install.sh)\n"
 
sleep 2s

cd ${TOOLKIT}

if [ ${SERIES} != 100 ]
    then
    echo -e "*** Setting DEPLOY state to 3 in System ROM ***\n" 
    ./statemgr -W DEPLOY 3 > /dev/null

    
    ## rerun hwdiscovery to find boot device
    echo "*** Discovering boot device"
    ./hpdiscovery -f ${HWDISC_FILE}
    sleep 5s

    ## use hwquery to fetch the boot dev node from hardware discovery file.
    export `./hwquery ${HWDISC_FILE} allboards.xml BOOTDEVNODE=DevNode`
    echo "    -Boot Device=${BOOTDEVNODE}"

    if [ -z ${BOOTDEVNODE} ]; 
	then
	    echo "!!! MISSING boot device dev node. Check that the drivers are loaded !!!"
	    exec /bin/bash
    fi

# end if for !=100
fi

ln -s ${BOOTDEVNODE} /dev/sssd
sleep 5s

echo -e "*** Clearing mbr and a few more sectors"
dd if=/dev/zero of=/dev/sssd bs=512 count=32 &> /dev/null

echo -e "*** Forcing kernel to re-read partition table"
sfdisk --re-read /dev/sssd &>/dev/null
sleep 5s

echo -e "*** Landing mbr\n"
dd if=${RAM_TOOLKIT_DIR}/extra_utils/generic.mbr of=/dev/sssd bs=512 count=1 &> /dev/null

echo "*** Creating 256M VFAT partition using sfdisk"
echo "0,256,6,*" | sfdisk -uM -D /dev/sssd &>/dev/null

echo -e "*** Forcing kernel to re-read partition table"
sfdisk --re-read /dev/sssd &>/dev/null
sleep 5s

## make symlink for first partition, usually sda1 or c0d0p1

## Smart Array partitions end in p1,  sda or hda partitons don't have the "p"
## set BOOTDEVPART variable for inserting partition information correctly when creating 
## syslinux.cfg file later in script

if test -e ${BOOTDEVNODE}1 ; 
    then
	ln -s ${BOOTDEVNODE}1 /dev/sssd1
	export BOOTDEVPART=1
    elif 
	test -e ${BOOTDEVNODE}p1 ; 
	then
	    ln -s ${BOOTDEVNODE}p1 /dev/sssd1
	    export BOOTDEVPART=p1
    else
	echo "Partition 1 missing, check that partition creation succeeded"
	exec /bin/bash
fi

###
### Copy image file to boot partiton
### Copy syslinux.cfg file to boot partition
### syslinux.cfg will get populated with correct info
###

if [ ${LinuxCOE} = 1 ];
    then
    echo -e "  -LinuxCOE configuration being used\n"
    sleep 2s
    
    case "$DISTRO" in
    
	REDHAT* | SLES* )
	        
		echo -e "*** Installing boot image on local disk"
		echo "  -Formatting disk"
		mkdosfs /dev/sssd1 > /dev/null 2>/dev/null
		echo "  -Installing syslinux"
		syslinux /dev/sssd1
		echo "*** Mounting local file system ***"
		echo "*** Installing boot files ***"
		mount -t vfat /dev/sssd1 /mnt/dos
		sleep 1s
		tar --directory=/mnt/dos --no-same-owner -xvf ${RAM_DATA_FILES}/${SERIAL_ID}/boot.tar &>/dev/null
		
		    case "${DISTRO}" in
		
			REDHAT* )
		
			cp -r /mnt/dos/isolinux/* /mnt/dos
			cp /mnt/dos/isolinux.cfg /mnt/dos/syslinux.cfg
			# fix syslinux.cfg to use server specific kickstart file
			# if more than one network interface will have link status change ksdevice=
			# to either ${IFACE} or the correct interface i.e. eth1 eth2 eth3                        
			sed -i "s|ks=[^ ]*|ks=nfs:${NFS_SERVER_IP}:${NFS_DATA_FILES}/${SERIAL_ID}/ks.cfg ksdevice=link|" "/mnt/dos/syslinux.cfg"
			# set install to start automatically in 30 seconds
			sed -i '3i\timeout 300' /mnt/dos/syslinux.cfg
			sed -i '3i\default install' /mnt/dos/syslinux.cfg
			echo -e " Using kickstart file for ${SERIAL_ID}"
		
		    ;;
		
			SLES* )
		
			# fix syslinux.cfg to use server specific automation files to keep 
			# the append line 255 character limit in check we are using info.txt
			# copy the info file to the local disk and edit as NFS mount is read only
			cp /mnt/dos/isolinux.cfg /mnt/dos/syslinux.cfg
			cp ${RAM_DATA_FILES}/${SERIAL_ID}/info.txt /mnt/dos
			sed -i "s|info[^ ]*|netdevice=${IFACE}|" "/mnt/dos/syslinux.cfg"
			sed -i "s|autoyast[^ ]*|info=hd:${BOOTDEVNODE}${BOOTDEVPART}/info.txt|" /mnt/dos/syslinux.cfg
			echo "AutoYaST: nfs://${NFS_SERVER_IP}/${NFS_DATA_FILES}/${SERIAL_ID}/autoyast.xml" >> /mnt/dos/info.txt
			# set install to start automatically in 30 seconds
			sed -i '3i\default install' /mnt/dos/syslinux.cfg
			sed -i '3i\timeout 300' /mnt/dos/syslinux.cfg
			echo -e " Using AutoYaST file for ${SERIAL_ID}"
			sleep 10s
		    ;;
		    esac
                ;;
        
	SOLARIS )
			echo -e "*** Installing boot image on local disk"
			echo "  -Formatting /dev/sssd1"
			mkdosfs /dev/sssd1 > /dev/null 2>/dev/null
			echo "*** Mounting local file system"
			### mount -t vfat /dev/sssd1 /mnt/dos
			mount /dev/sssd1 /mnt/dos
			sleep 1s
			cd ${TOOLKIT}
			# install grub
			source instgrub.sh
			#cp ${RAM_TOOLKIT_DIR}/solaris/mboot.c32 /mnt/dos
			cp ${RAM_TOOLKIT_DIR}/solaris/multiboot /mnt/dos
			cp ${RAM_TOOLKIT_DIR}/solaris/x86.miniroot /mnt/dos
			cp ${RAM_TOOLKIT_DIR}/solaris/grub.conf /mnt/dos/boot/grub
			sleep 10s
			
                ;;
	
	* )
			echo "Not defined"
		;;
			
    esac
    
    # End LinuxCOE

    else

    # Most files for this section are located at SSSTK/images
    # personalization information is located at SSSTK/data_files 
    
    case "$DISTRO" in
    
	REDHAT* | SLES* )

			echo "  -Formatting /dev/sssd1"
			mkdosfs /dev/sssd1 &>/dev/null
			echo "  -Installing syslinux"
			syslinux /dev/sssd1
			echo "*** Mounting ${BOOTDEVNODE} to /mnt/dos"
			mount -t vfat /dev/sssd1 /mnt/dos
			sleep 5s
			echo -e "*** Installing boot files on local disk"
			cp -a ${RAM_IMAGE_FILES}/${DISTRO}-${ARCH}/* /mnt/dos
			cp -a ${RAM_IMAGE_FILES}/boot.msg /mnt/dos/boot.msg
			sleep 10s

		    case "${DISTRO}" in
		
			REDHAT* )
		
			# fix syslinux.cfg to use server specific kickstart file
			# Red Hat has some PCI enumneration issues with som ProLiant server
			# if more than one network interface will have link status change ksdevice=
			# to either ${IFACE} or the correct interface i.e. eth1 eth2 eth3
			echo -e "*** Creating syslinux.cfg"
			cp -a ${RAM_IMAGE_FILES}/rh-syslinux /mnt/dos/syslinux.cfg
			sed -i "s|GROKINFO[^ ]*|ks=nfs:${NFS_SERVER_IP}:${NFS_DATA_FILES}/${SERIAL_ID}/ks.cfg ksdevice=link|" "/mnt/dos/syslinux.cfg"
			sed -i "s|DISTROFULL[^ ]*|${DISTROFULL}|" "/mnt/dos/boot.msg"
			sleep 10s
		
		    ;;
		
			SLES* )
		
			# fix syslinux.cfg to use server specific autoyast file
			echo -e "*** Creating syslinux.cfg"
			cp -a ${RAM_IMAGE_FILES}/suse-syslinux /mnt/dos/syslinux.cfg
			cp ${RAM_DATA_FILES}/${SERIAL_ID}/info.txt /mnt/dos
			echo "AutoYaST: nfs://${NFS_SERVER_IP}/${NFS_DATA_FILES}/${SERIAL_ID}/autoyast.xml" >> /mnt/dos/info.txt
			sed -i "s|GROKINFO[^ ]*|info=hd:${BOOTDEVNODE}${BOOTDEVPART}/info.txt netdevice=${IFACE}|" "/mnt/dos/syslinux.cfg"
			sed -i "s|DISTROFULL[^ ]*|${DISTROFULL}|" "/mnt/dos/boot.msg"
			sleep 10s
		    ;;

		    esac

                ;;

    
	SOLARIS )
			echo -e "*** Installing boot image on local disk"
			echo "   -Formatting /dev/sssd1"
			# copy needed libraries for mke2fs
			## cp ${RAM_TOOLKIT_DIR}/extra_utils/lib*.* /lib
			### ${RAM_TOOLKIT_DIR}/extra_utils/mke2fs /dev/sssd1
			mkdosfs /dev/sssd1 &>/dev/null
			echo "*** Mounting ${BOOTDEVNODE}p1 to /mnt/dos"
			mount -t vfat /dev/sssd1 /mnt/dos
			### mount /dev/sssd1 /mnt/dos
			sleep 1s
			cd ${TOOLKIT}
			source instgrub.sh
			cp ${RAM_TOOLKIT_DIR}/solaris/multiboot /mnt/dos/
			cp ${RAM_TOOLKIT_DIR}/solaris/x86.miniroot /mnt/dos/
			cp ${RAM_TOOLKIT_DIR}/solaris/grub.conf /mnt/dos/boot/grub/
			sleep 5s
                ;;

    esac
    
fi    
    
sleep 5s
cd ${TOOLKIT}

## unmount disk
umount /mnt/dos 2> /dev/null
umount ${RAM_TOOLKIT_DIR} 2> /dev/null
umount -a 2> /dev/null
echo -e "Rebooting to hard disk..."
sleep 5s

#set state to 99 to make systems boot from local drive
./statemgr -W DEPLOY 99 > /dev/null

# Debug stopping point remove or comment next line
# exec /bin/bash

### the REBOOT utilitiy can override the default boot order
### reboot C: 
### reboot PXE

/bin/reboot c:

